==> cai_causal_graph-0.1.1.dev3.tar.gz: cai_causal_graph-0.1.1.dev3/README.md <==
# cai-causal-graph

![causaLens logo](cl-logo.png)

## From causaLens, a Causal AI package for causal graphs
Documentation, including a quickstart and code reference docs, can be found [here](https://causalgraph.causalens.com/).

[![PyPI version](https://img.shields.io/pypi/v/cai-causal-graph.svg?color=informational)](https://pypi.org/project/cai-causal-graph/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cai-causal-graph.svg?color=informational)](https://pypi.org/project/cai-causal-graph/)
[![LICENSE](https://img.shields.io/badge/License-Apache_2.0-informational.svg)](https://www.apache.org/licenses/LICENSE-2.0)

![TEST](https://github.com/causalens/cai-causal-graph/workflows/MAIN-CHECKS/badge.svg?branch=main)
![DEPENDENCIES](https://github.com/causalens/cai-causal-graph/workflows/DEPENDENCIES-CHECKS/badge.svg?branch=main) 
![RELEASE](https://github.com/causalens/cai-causal-graph/workflows/RELEASE/badge.svg) 
![POST-RELEASE](https://github.com/causalens/cai-causal-graph/workflows/POST-RELEASE/badge.svg?branch=main) 

[![LINTING: mypy](https://img.shields.io/badge/Linting-mypy-informational.svg)](https://mypy-lang.org/)
[![SECURITY: bandit](https://img.shields.io/badge/Security-bandit-informational.svg)](https://github.com/PyCQA/bandit)
![INTERROGATE](interrogate_badge.svg)

> **Note**  
> The current development cycle of this branch is `v0.1.x` (stable).
 
## License

`cai-causal-graph` is open source and licensed under the [Apache-2.0 license](https://github.com/causalens/cai-causal-graph/blob/main/LICENSE).

==> cai_causal_graph-0.1.2.dev2.tar.gz: cai_causal_graph-0.1.2.dev2/README.md <==
# cai-causal-graph

![causaLens logo](https://github.com/causalens/cai-causal-graph/blob/main/cl-logo.png?raw=true)

## From causaLens, a Causal AI package for causal graphs
Documentation, including a quickstart and code reference docs, can be found [here](https://causalgraph.causalens.com/).

[![PyPI version](https://img.shields.io/pypi/v/cai-causal-graph.svg?color=informational)](https://pypi.org/project/cai-causal-graph/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cai-causal-graph.svg?color=informational)](https://pypi.org/project/cai-causal-graph/)
[![LICENSE](https://img.shields.io/badge/License-Apache_2.0-informational.svg)](https://www.apache.org/licenses/LICENSE-2.0)

![TEST](https://github.com/causalens/cai-causal-graph/workflows/MAIN-CHECKS/badge.svg?branch=main)
![DEPENDENCIES](https://github.com/causalens/cai-causal-graph/workflows/DEPENDENCIES-CHECKS/badge.svg?branch=main) 
![RELEASE](https://github.com/causalens/cai-causal-graph/workflows/RELEASE/badge.svg) 
![POST-RELEASE](https://github.com/causalens/cai-causal-graph/workflows/POST-RELEASE/badge.svg?branch=main) 

[![LINTING: mypy](https://img.shields.io/badge/Linting-mypy-informational.svg)](https://mypy-lang.org/)
[![SECURITY: bandit](https://img.shields.io/badge/Security-bandit-informational.svg)](https://github.com/PyCQA/bandit)
![INTERROGATE](https://github.com/causalens/cai-causal-graph/blob/main/interrogate_badge.svg?raw=true)

> **Note**  
> The current development cycle of this branch is `v0.1.x` (stable).
 
## License

`cai-causal-graph` is open source and licensed under the [Apache-2.0 license](https://github.com/causalens/cai-causal-graph/blob/main/LICENSE).
